from .sqlalchemy import SQLAlchemy
from .db import base

db = SQLAlchemy()
# db.register_base(base)